@@ -14,7 +14,7 @@
 #include "maskset.h"
 
 #define NAME	"lkstm"
-#define VERSION "1.5"
+#define VERSION "1.6"
 
 void usage(void);
 
@@ -79,7 +79,7 @@ void usage(void)
 	printf("\t\t-m maskset_id | -n maskset_name\n");
 	printf("read\t\tOutput a content of maskset(s).\n");
 	printf("\t\t<OPTION>\n");
-	printf("\t\t[-m maskset_id | -n maskset_name] [-A] [-a] [-d]\n");
+	printf("\t\t[-m maskset_id | -n maskset_name] [-A] [-a] [-d] [-E etype_list_file]\n");
 	printf("set\t\tChange to sepecified maskset.\n");
 	printf("\t\t<OPTION>\n");
 	printf("\t\t-m maskset_id | -n maskset_name\n");
@@ -191,7 +191,7 @@ void call_read(int *argc, char **argv)
 	int disp = 0;
 	lkst_maskset_id id = LKST_MASKSET_ID_VOID;
 
-	while((c = getopt(*argc, argv, "m:n:Aad")) != EOF) {
+	while((c = getopt(*argc, argv, "m:n:AadE:")) != EOF) {
 		switch(c) {
 		case 'm' :
 			id = STR2MID(optarg);
@@ -208,6 +208,11 @@ void call_read(int *argc, char **argv)
 		case 'd' :
 			disp = 1;
 			break;
+		case 'E' :
+			if ( lkst_etype_desc_load(optarg) < 0 ) {
+				fprintf(stderr, "Error: %s(%s)", strerror(errno),optarg);
+			}
+			break;
 		default :
 			usage();
 		}
