@@ -170,7 +170,7 @@ static void maskset_read_disp(struct lkst_maskset_param *param,
 		printf("# event_type\tevent_name\t\tevent_handler_ID\n");
 		for (i = 0; i < maskset->len; i++) {
 			event_type = maskset->entry[i].event_type,
-				event_type_name = lkst_event_type_descriptions[event_type];
+				event_type_name = lkst_etype_desc[event_type].mnemonic;
 			if (event_type_name || all)
 				printf(" 0x%03x\t\t%-24s\t0x%02x\n",
 				       event_type,
